bayespy.inference.vmp.nodes.wishart.WishartMoments.compute_dims_from_values
===========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.wishart

.. automethod:: WishartMoments.compute_dims_from_values